fn validate_hs256_legacy_claim<T: DeserializeOwned>(
token: &str,
key: &JwtKey,
) -> Result<T, Error>Expand description
Decodes claims in compatibility mode and validates legacy expiration_time manually.
fn validate_hs256_legacy_claim<T: DeserializeOwned>(
token: &str,
key: &JwtKey,
) -> Result<T, Error>Decodes claims in compatibility mode and validates legacy expiration_time manually.